*WMS* steht für [Web Map Service](https://de.wikipedia.org/wiki/Web_Map_Service).
Ein WMS kann eine oder mehrere Kartenlayer beeinhalten.

**WMS URL**: Die URL eines WMS, z.B. 
`https://geodienste.hamburg.de/HH_WMS_Gewaesserunterhaltung`.

**WMS Layer**: Sobald eine gültige WMS-URL eingegeben wurde, kann hier eine der 
verfügbaren Ebenen auswählt werden.
